@@ -23,13 +23,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifndef GDK_PIXBUF_CORE_H
+#define GDK_PIXBUF_CORE_H
+
 #if defined(GDK_PIXBUF_DISABLE_SINGLE_INCLUDES) && !defined (GDK_PIXBUF_H_INSIDE) && !defined (GDK_PIXBUF_COMPILATION)
 #error "Only <gdk-pixbuf/gdk-pixbuf.h> can be included directly."
 #endif
 
-#ifndef GDK_PIXBUF_CORE_H
-#define GDK_PIXBUF_CORE_H
-
 #include <glib.h>
 #include <glib-object.h>
 #include <gio/gio.h>
@@ -298,6 +298,13 @@ GdkPixbuf *gdk_pixbuf_new_from_file_at_scale (const char *filename,
 					      int         height,
 					      gboolean    preserve_aspect_ratio,
 					      GError    **error);
+GdkPixbuf *gdk_pixbuf_new_from_resource (const char *resource_path,
+					 GError    **error);
+GdkPixbuf *gdk_pixbuf_new_from_resource_at_scale (const char *resource_path,
+						  int         width,
+						  int         height,
+						  gboolean    preserve_aspect_ratio,
+						  GError    **error);
 
 GdkPixbuf *gdk_pixbuf_new_from_data (const guchar *data,
 				     GdkColorspace colorspace,
