@@ -117,7 +117,6 @@ typedef struct
 {
         GdkPixbufAnimation *animation;
         gboolean closed;
-        gboolean holds_threadlock;
         guchar header_buf[LOADER_HEADER_SIZE];
         gint header_buf_offset;
         GdkPixbufModule *image_module;
@@ -249,9 +248,6 @@ gdk_pixbuf_loader_finalize (GObject *object)
 
         if (!priv->closed) {
                 g_warning ("GdkPixbufLoader finalized without calling gdk_pixbuf_loader_close() - this is not allowed. You must explicitly end the data stream to the loader before dropping the last reference.");
-                if (priv->holds_threadlock) {
-                        _gdk_pixbuf_unlock (priv->image_module);
-                }
         }
         if (priv->animation)
                 g_object_unref (priv->animation);
@@ -321,21 +317,23 @@ gdk_pixbuf_loader_prepare (GdkPixbuf          *pixbuf,
 			   gpointer            loader)
 {
         GdkPixbufLoaderPrivate *priv = GDK_PIXBUF_LOADER (loader)->priv;
+        gint width, height;
         g_return_if_fail (pixbuf != NULL);
 
+        width = anim ? gdk_pixbuf_animation_get_width (anim) :
+                gdk_pixbuf_get_width (pixbuf);
+        height = anim ? gdk_pixbuf_animation_get_height (anim) :
+                gdk_pixbuf_get_height (pixbuf);
+
         if (!priv->size_fixed) 
                 {
                         /* Defend against lazy loaders which don't call size_func */
-                        gint width = gdk_pixbuf_get_width (pixbuf);
-                        gint height = gdk_pixbuf_get_height (pixbuf);
-                        
                         gdk_pixbuf_loader_size_func (&width, &height, loader);
                 }
 
         priv->needs_scale = FALSE;
         if (priv->width > 0 && priv->height > 0 &&
-            (priv->width != gdk_pixbuf_get_width (pixbuf) ||
-             priv->height != gdk_pixbuf_get_height (pixbuf)))
+            (priv->width != width || priv->height != height))
                 priv->needs_scale = TRUE;
 
         if (anim)
@@ -345,8 +343,8 @@ gdk_pixbuf_loader_prepare (GdkPixbuf          *pixbuf,
   
 	if (priv->needs_scale) {
 		priv->animation  = GDK_PIXBUF_ANIMATION (_gdk_pixbuf_scaled_anim_new (anim,
-                                         (double) priv->width / gdk_pixbuf_get_width (pixbuf),
-                                         (double) priv->height / gdk_pixbuf_get_height (pixbuf),
+                                         (double) priv->width / width,
+                                         (double) priv->height / height,
 					  1.0));
 			g_object_unref (anim);
 	}
@@ -440,10 +438,6 @@ gdk_pixbuf_loader_load_module (GdkPixbufLoader *loader,
                         return 0;
                 }
 
-	if (!priv->holds_threadlock) {
-                priv->holds_threadlock = _gdk_pixbuf_lock (priv->image_module);
-        }
-
         priv->context = priv->image_module->begin_load (gdk_pixbuf_loader_size_func,
                                                         gdk_pixbuf_loader_prepare,
                                                         gdk_pixbuf_loader_update,
@@ -801,10 +795,6 @@ gdk_pixbuf_loader_close (GdkPixbufLoader *loader,
                 }
   
         priv->closed = TRUE;
-	if (priv->image_module && priv->holds_threadlock) {
-                _gdk_pixbuf_unlock (priv->image_module);
-                priv->holds_threadlock = FALSE;
-        }
 
         if (priv->needs_scale) 
                 {
